## WebSocket channels for ASGI


## Installation

Install `malanka` using PIP or poetry:

```bash
pip install malanka
# or
poetry add malanka
```

## Quick start

See example application in `examples/` directory of this repository.
